@@ -1,23 +1,90 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2005 Insecure.Com LLC.
-#
-# Author: Adriano Monteiro Marques <py.adriano@gmail.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+# ***********************IMPORTANT NMAP LICENSE TERMS************************
+# *                                                                         *
+# * The Nmap Security Scanner is (C) 1996-2009 Insecure.Com LLC. Nmap is    *
+# * also a registered trademark of Insecure.Com LLC.  This program is free  *
+# * software; you may redistribute and/or modify it under the terms of the  *
+# * GNU General Public License as published by the Free Software            *
+# * Foundation; Version 2 with the clarifications and exceptions described  *
+# * below.  This guarantees your right to use, modify, and redistribute     *
+# * this software under certain conditions.  If you wish to embed Nmap      *
+# * technology into proprietary software, we sell alternative licenses      *
+# * (contact sales@insecure.com).  Dozens of software vendors already       *
+# * license Nmap technology such as host discovery, port scanning, OS       *
+# * detection, and version detection.                                       *
+# *                                                                         *
+# * Note that the GPL places important restrictions on "derived works", yet *
+# * it does not provide a detailed definition of that term.  To avoid       *
+# * misunderstandings, we consider an application to constitute a           *
+# * "derivative work" for the purpose of this license if it does any of the *
+# * following:                                                              *
+# * o Integrates source code from Nmap                                      *
+# * o Reads or includes Nmap copyrighted data files, such as                *
+# *   nmap-os-db or nmap-service-probes.                                    *
+# * o Executes Nmap and parses the results (as opposed to typical shell or  *
+# *   execution-menu apps, which simply display raw Nmap output and so are  *
+# *   not derivative works.)                                                * 
+# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
+# *   installer, such as those produced by InstallShield.                   *
+# * o Links to a library or executes a program that does any of the above   *
+# *                                                                         *
+# * The term "Nmap" should be taken to also include any portions or derived *
+# * works of Nmap.  This list is not exclusive, but is meant to clarify our *
+# * interpretation of derived works with some common examples.  Our         *
+# * interpretation applies only to Nmap--we don't speak for other people's  *
+# * GPL works.                                                              *
+# *                                                                         *
+# * If you have any questions about the GPL licensing restrictions on using *
+# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
+# * we also offer alternative license to integrate Nmap into proprietary    *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates as well as helping to     *
+# * fund the continued development of Nmap technology.  Please email        *
+# * sales@insecure.com for further information.                             *
+# *                                                                         *
+# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * permission to link the code of this program with any version of the     *
+# * OpenSSL library which is distributed under a license identical to that  *
+# * listed in the included COPYING.OpenSSL file, and distribute linked      *
+# * combinations including the two. You must obey the GNU GPL in all        *
+# * respects for all of the code used other than OpenSSL.  If you modify    *
+# * this file, you may extend this exception to your version of the file,   *
+# * but you are not obligated to do so.                                     *
+# *                                                                         *
+# * If you received these files with a written license agreement or         *
+# * contract stating terms other than the terms above, then that            *
+# * alternative license agreement takes precedence over these comments.     *
+# *                                                                         *
+# * Source is provided to this software because we believe users have a     *
+# * right to know exactly what a program is going to do before they run it. *
+# * This also allows you to audit the software for security holes (none     *
+# * have been found so far).                                                *
+# *                                                                         *
+# * Source code also allows you to port Nmap to new platforms, fix bugs,    *
+# * and add new features.  You are highly encouraged to send your changes   *
+# * to nmap-dev@insecure.org for possible incorporation into the main       *
+# * distribution.  By sending these changes to Fyodor or one of the         *
+# * Insecure.Org development mailing lists, it is assumed that you are      *
+# * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
+# * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
+# * will always be available Open Source, but this is important because the *
+# * inability to relicense code has caused devastating problems for other   *
+# * Free Software projects (such as KDE and NASM).  We also occasionally    *
+# * relicense the code to third parties as discussed above.  If you wish to *
+# * specify special license conditions of your contributions, just say so   *
+# * when you send them.                                                     *
+# *                                                                         *
+# * This program is distributed in the hope that it will be useful, but     *
+# * WITHOUT ANY WARRANTY; without even the implied warranty of              *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+# * General Public License v2.0 for more details at                         *
+# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
+# * included with Nmap.                                                     *
+# *                                                                         *
+# ***************************************************************************/
 
 import re
 
@@ -27,7 +94,7 @@ from ConfigParser import DuplicateSectionError, NoSectionError, NoOptionError
 from zenmapCore.Paths import Path
 from zenmapCore.UmitLogging import log
 from zenmapCore.UmitConfigParser import UmitConfigParser
-from zenmapCore.I18N import _
+import zenmapCore.I18N
 
 # This is the global configuration parser object that represents the contents of
 # zenmap.conf. It should be initialized once by the application. Most
@@ -46,43 +113,6 @@ except ImportError:
 def is_maemo():
     return MAEMO
 
-class UmitConf(object):
-    def save_changes(self):
-        config_parser.save_changes()
-
-    def get_colored_diff(self):
-        try:
-            cd = config_parser.get('diff', 'colored_diff')
-            if cd == "False" or \
-                cd == "false" or \
-                cd == "0" or \
-                cd == "" or \
-                cd == False:
-                return False
-            return True
-        except:
-            return True
-
-    def set_colored_diff(self, enable):
-        if not config_parser.has_section('diff'):
-            config_parser.add_section('diff')
-
-        config_parser.set('diff', 'colored_diff', str(enable))
-
-    def get_diff_mode(self):
-        try: return config_parser.get('diff', 'diff_mode')
-        except: return "compare"
-
-    def set_diff_mode(self, diff_mode):
-        if not config_parser.has_section('diff'):
-            config_parser.add_section('diff')
-        
-        config_parser.set('diff', 'diff_mode', diff_mode)
-
-    colored_diff = property(get_colored_diff, set_colored_diff)
-    diff_mode = property(get_diff_mode, set_diff_mode)
-
-
 class SearchConfig(UmitConfigParser, object):
     section_name = "search"
 
@@ -96,7 +126,7 @@ class SearchConfig(UmitConfigParser, object):
     def create_section(self):
         config_parser.add_section(self.section_name)
         self.directory = ""
-        self.file_extension = "usr"
+        self.file_extension = "xml"
         self.save_time = "60;days"
         self.store_results = True
         self.search_db = True
@@ -124,7 +154,7 @@ class SearchConfig(UmitConfigParser, object):
         self._set_it("directory", directory)
 
     def get_file_extension(self):
-        return self._get_it("file_extension", "usr").split(";")
+        return self._get_it("file_extension", "xml").split(";")
 
     def set_file_extension(self, file_extension):
         if type(file_extension) == type([]):
@@ -162,13 +192,13 @@ class SearchConfig(UmitConfigParser, object):
 
     def get_time_list(self):
         # Time as key, seconds a value
-        return {_("Hours"): 60 * 60,
-                _("Days"): 60 * 60 * 24,
-                _("Weeks"): 60 * 60 * 24 * 7,
-                _("Months"): 60 * 60 * 24 * 7 * 30,
-                _("Years"): 60 * 60 * 24 * 7 * 30 * 12,
-                _("Minutes"): 60,
-                _("Seconds"): 1}
+        return {"hours": 60 * 60,
+                "days": 60 * 60 * 24,
+                "weeks": 60 * 60 * 24 * 7,
+                "months": 60 * 60 * 24 * 7 * 30,
+                "years": 60 * 60 * 24 * 7 * 30 * 12,
+                "minutes": 60,
+                "seconds": 1}
     
     directory = property(get_directory, set_directory)
     file_extension = property(get_file_extension, set_file_extension)
@@ -220,31 +250,10 @@ class Profile(UmitConfigParser, object):
         except DuplicateSectionError:
             return None
 
-        # Set each of the attributes ("command", "options", "description") in
-        # the ConfigParser.
+        # Set each of the attributes ("command", "description") in the
+        # ConfigParser.
         for attr in attributes:
-            if attr == "options":
-                # We handle the "options" attribute specially because it is a
-                # dict, not a plain string.
-                options = attributes["options"]
-                assert type(options) == dict
-
-                # The "options" attribute looks like, for example,
-                #   options = Ports to scan,Verbose,Aggressive
-                self._set_it(profile_name, "options", ",".join(options.keys()))
-
-                # Some of the options take an argument, which is also stored in
-                # the scan profiles file. Arguments are the values associated
-                # with keys in the dict, if not None. For example,
-                #   ports to scan = 1-1024
-                # might be stored in the file, meaning "-p1-1024". (Notice that
-                # case is not significant.)
-                for opt in options:
-                    if options[opt]:
-                        self._set_it(profile_name, opt, options[opt])
-            else:
-                # The other attributes are just strings so simply set them.
-                self._set_it(profile_name, attr, attributes[attr])
+            self._set_it(profile_name, attr, attributes[attr])
 
         self.save_changes()
 
@@ -260,55 +269,31 @@ class Profile(UmitConfigParser, object):
 
 class CommandProfile (Profile, object):
     """This class is a wrapper around Profile that provides accessors for the
-    attributes of a profile: command, options, and description"""
+    attributes of a profile: command and description"""
     def __init__(self, user_profile = None):
         Profile.__init__(self, user_profile)
         
     def get_command(self, profile):
-        return self._get_it(profile, 'command')
+        command_string = self._get_it(profile, 'command')
+        # Old versions of Zenmap used to append "%s" to commands and use that to
+        # substitute the target. Ignore it if present.
+        if command_string.endswith("%s"):
+            command_string = command_string[:-len("%s")]
+        return command_string
 
     def get_description(self, profile):
         return self._get_it(profile, 'description')
     
-    def get_options(self, profile):
-        """Return a dict of options and their corresponding arguments. Use None
-        as the value for options that don't have an argument."""
-        dic = {}
-        options_str = self._get_it(profile, 'options')
-        # If we get back an empty string, there are no options.
-        if options_str.strip() == '':
-            return dic
-        for opt in options_str.split(','):
-            opt = opt.strip()
-            # Arguments for options are stored in the same way as the list of
-            # options itself, as name-value pairs, with the option as the name
-            # and the argument as the value. So for example you might have
-            #   options = Ports to scan,Verbose,Aggressive
-            #   ports to scan = 1-1024
-            # and case is not significant in the option name.
-            try:
-                dic[unicode(opt)] = self._get_it(profile, opt)
-            except NoOptionError:
-                dic[unicode(opt)] = None
-        return dic
-
     def set_command(self, profile, command=''):
         self._set_it(profile, 'command', command)
 
     def set_description(self, profile, description=''):
         self._set_it(profile, 'description', description)
     
-    def set_options(self, profile, options={}):
-        for opt in options:
-            if options[opt]:
-                self._set_it(profile, opt, options[opt])
-        self._set_it(profile, 'options', ",".join(options.keys()))
-
     def get_profile(self, profile_name):
         return {'profile':profile_name, \
                 'command':self.get_command(profile_name), \
-                'description':self.get_description(profile_name), \
-                'options':self.get_options(profile_name)}
+                'description':self.get_description(profile_name)}
 
 
 class NmapOutputHighlight(object):
@@ -500,58 +485,6 @@ class NmapOutputHighlight(object):
                             "highlight":[65535, 65535, 65535],
                             "regex":"^(\w{2,}[\s]{,3}){,4}:"}}
 
-class DiffColors(object):
-    section_name = "diff_colors"
-
-    def save_changes(self):
-        config_parser.save_changes()
-
-    def __get_it(self, p_name):
-        return self.sanity_settings(config_parser.get(self.section_name, p_name))
-
-    def __set_it(self, property_name, settings):
-        settings = self.sanity_settings(settings)
-        config_parser.set(self.section_name, property_name, settings)
-
-    def sanity_settings(self, settings):
-        log.debug(">>> Sanitize %s" % str(settings))
-        
-        tuple_regex = "[\(\[]\s?(\d+)\s?,\s?(\d+)\s?,\s?(\d+)\s?[\)\]]"
-        if isinstance(settings, basestring):
-            settings = [int(t) for t in re.findall(tuple_regex, settings)[0]]
-
-        return settings
-
-    def get_unchanged(self):
-        return self.__get_it("unchanged")
-
-    def set_unchanged(self, settings):
-        self.__set_it("unchanged", settings)
-
-    def get_added(self):
-        return self.__get_it("added")
-
-    def set_added(self, settings):
-        self.__set_it("added", settings)
-
-    def get_modified(self):
-        return self.__get_it("modified")
-
-    def set_modified(self, settings):
-        self.__set_it("modified", settings)
-
-    def get_not_present(self):
-        return self.__get_it("not_present")
-
-    def set_not_present(self, settings):
-        self.__set_it("not_present", settings)
-
-    unchanged = property(get_unchanged, set_unchanged)
-    added = property(get_added, set_added)
-    modified = property(get_modified, set_modified)
-    not_present = property(get_not_present, set_not_present)
-
-
 # Retrieve details from zenmap.conf regarding paths subsection
 # (e.g. nmap_command_path) - jurand
 class PathsConfig(object):
@@ -560,23 +493,30 @@ class PathsConfig(object):
     # This accounts for missing entries conf file.
     # Defaults to "nmap" if these errors occur.
     # NoOptionError, NoSectionError
-    def __get_it(self, p_name):
-	try:
-        	return config_parser.get(self.section_name, p_name)
-	except (NoOptionError,NoSectionError):
-		log.debug(">>> nmap command path not configured. Using default 'nmap'.")
-		return "nmap"
+    def __get_it(self, p_name, default):
+        try:
+            return config_parser.get(self.section_name, p_name)
+        except (NoOptionError,NoSectionError):
+            log.debug(">>> Using default \"%s\" for \"%s\"." % (default, p_name))
+            return default
 
     def __set_it(self, property_name, settings):
         config_parser.set(self.section_name, property_name, settings)
 
     def get_nmap_command_path(self):
-        return self.__get_it("nmap_command_path")
+        return self.__get_it("nmap_command_path", "nmap")
 
     def set_nmap_command_path(self, settings):
         self.__set_it("nmap_command_path", settings)
 
+    def get_ndiff_command_path(self):
+        return self.__get_it("ndiff_command_path", "ndiff")
+
+    def set_ndiff_command_path(self, settings):
+        self.__set_it("ndiff_command_path", settings)
+
     nmap_command_path = property(get_nmap_command_path, set_nmap_command_path)
+    ndiff_command_path = property(get_ndiff_command_path, set_ndiff_command_path)
 
 # Exceptions
 class ProfileNotFound:
@@ -590,7 +530,3 @@ class ProfileCouldNotBeSaved:
         self.profile = profile
     def __str__ (self):
         return "Profile named '"+self.profile+"' could not be saved!"
-
-
-if __name__ == "__main__":
-    pass
